"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));

var _acorn = require("acorn");

var _acornWalk = require("acorn-walk");

var _fs = _interopRequireDefault(require("fs"));

var _util = require("util");

var _prettier = _interopRequireDefault(require("prettier"));

// const schema = {
//   type: 'object',
//   properties: {},
// }
const loader = function (content, sourceMap) {
  const callback = this.async();
  const declarationPath = this.resourcePath + '.d.ts';
  const parsed = (0, _acorn.parse)(content, {
    sourceType: 'module',
    ecmaVersion: 'latest'
  });
  const keys = [];
  (0, _acornWalk.simple)(parsed, {
    ExpressionStatement(node) {
      (0, _acornWalk.simple)(node, {
        // console.log(node)
        AssignmentExpression(node) {
          (0, _acornWalk.simple)(node, {
            Property(node) {
              const key = node.key.value;
              keys.push(key);
            }

          });
        }

      });
    },

    ExportNamedDeclaration(node) {
      (0, _acornWalk.simple)(node, {
        VariableDeclarator(node) {
          keys.push(node.id.name);
        }

      });
    }

  });

  if (!keys.length) {
    callback(undefined, content);
    return;
  }

  const declarations = keys.map(key => `${key}: string;`).join('\n');
  const fileContent = `
  interface CSSModules {
    ${declarations}
  }
  export const cssModules: CSSModules
  export default cssModules
`;

  const prettierConfig = _prettier.default.resolveConfig.sync(declarationPath);

  const formattedContent = _prettier.default.format(fileContent, (0, _objectSpread2.default)((0, _objectSpread2.default)({}, prettierConfig), {}, {
    parser: 'typescript'
  }));

  (0, _util.promisify)(_fs.default.writeFile)(declarationPath, formattedContent, {
    encoding: 'utf-8'
  }).then(() => {
    callback(undefined, content);
  }) // istanbul ignore next
  .catch(
  /* istanbul ignore next */
  err => {
    callback(err, content);
  });
};

var _default = loader;
exports.default = _default;